@@ -4,6 +4,7 @@ require "active_support/core_ext/module/attribute_accessors"
 require "active_support/deprecation"
 require "active_support/notifications"
 
+require "factory_bot/internal"
 require "factory_bot/definition_hierarchy"
 require "factory_bot/configuration"
 require "factory_bot/errors"
@@ -31,6 +32,7 @@ require "factory_bot/declaration"
 require "factory_bot/sequence"
 require "factory_bot/attribute_list"
 require "factory_bot/trait"
+require "factory_bot/enum"
 require "factory_bot/aliases"
 require "factory_bot/definition"
 require "factory_bot/definition_proxy"
@@ -45,22 +47,16 @@ require "factory_bot/decorator/invocation_tracker"
 require "factory_bot/decorator/new_constructor"
 require "factory_bot/linter"
 require "factory_bot/version"
-require "factory_bot/internal"
 
 module FactoryBot
-  Deprecation = ActiveSupport::Deprecation.new("6.0", "factory_bot")
-
-  def self.configuration
-    Internal.configuration
-  end
-
-  def self.reset_configuration
-    Internal.reset_configuration
-  end
+  Deprecation = ActiveSupport::Deprecation.new("7.0", "factory_bot")
 
   mattr_accessor :use_parent_strategy, instance_accessor: false
   self.use_parent_strategy = true
 
+  mattr_accessor :automatically_define_enum_traits, instance_accessor: false
+  self.automatically_define_enum_traits = true
+
   # Look for errors in factories and (optionally) their traits.
   # Parameters:
   # factories - which factories to lint; omit for all factories
@@ -71,55 +67,25 @@ module FactoryBot
   def self.lint(*args)
     options = args.extract_options!
     factories_to_lint = args[0] || FactoryBot.factories
-    Linter.new(factories_to_lint, options).lint!
+    Linter.new(factories_to_lint, **options).lint!
+  end
+
+  # Set the starting value for ids when using the build_stubbed strategy
+  #
+  # Arguments:
+  # * starting_id +Integer+
+  #   The new starting id value.
+  def self.build_stubbed_starting_id=(starting_id)
+    Strategy::Stub.next_id = starting_id - 1
   end
 
   class << self
-    delegate :callbacks,
-             :callback_names,
-             :constructor,
-             :factories,
-             :initialize_with,
-             :sequences,
-             :skip_create,
-             :strategies,
-             :to_create,
-             :traits,
-             to: :configuration
-
-    delegate :factory_by_name,
-             :register_callback,
-             :register_default_callbacks,
-             :register_default_strategies,
-             :register_factory,
-             :register_sequence,
-             :register_strategy,
-             :register_trait,
-             :rewind_sequences,
-             :sequence_by_name,
-             :strategy_by_name,
-             :trait_by_name,
-             to: Internal
-
-    attr_accessor :allow_class_lookup
-
-    deprecate :allow_class_lookup,
-              :allow_class_lookup=,
-              :callback_names,
-              :factory_by_name,
-              :register_callback,
-              :register_default_callbacks,
-              :register_default_strategies,
-              :register_factory,
-              :register_trait,
-              :sequence_by_name,
-              :sequences,
-              :strategies,
-              :trait_by_name,
-              :traits,
-              deprecator: Deprecation
+    delegate :factories,
+      :register_strategy,
+      :rewind_sequences,
+      :strategy_by_name,
+      to: Internal
   end
 end
 
 FactoryBot::Internal.register_default_strategies
-FactoryBot::Internal.register_default_callbacks
