@@ -7,7 +7,7 @@ module FactoryBot
     attr_accessor :definition_file_paths
   end
 
-  self.definition_file_paths = %w(factories test/factories spec/factories)
+  self.definition_file_paths = %w[factories test/factories spec/factories]
 
   def self.find_definitions
     absolute_definition_file_paths = definition_file_paths.map { |path| File.expand_path(path) }
